@@ -137,6 +137,7 @@ class DB:
     def _put(self, key: ItemKey, item: Dict, expect_if_item_exists: Dict = None):
         assert key.name in item
         assert not key.secondary or key.secondary.name in item
+        kwargs = {"Item": item}
         if expect_if_item_exists:
             statements = []
             expression_values = {}
@@ -144,17 +145,16 @@ class DB:
                 statements.append(f"{name}=:{name}")
                 expression_values[f":{name}"] = value
             condition_expression = " AND ".join(statements)
-            condition_expression = f"({condition_expression}) OR {key.name}<>:{key.name}"  # or item does not exist
+            # or item does not exist
+            condition_expression = f"({condition_expression}) OR {key.name}<>:{key.name}"
             expression_values[key.name] = key.value
-        else:
-            expression_values = None
-            condition_expression = None
+            kwargs = {
+                **kwargs,
+                "ConditionExpression": condition_expression,
+                "ExpressionAttributeValues": expression_values,
+            }
         try:
-            self._table.put_item(
-                Item=item,
-                ConditionExpression=condition_expression,
-                ExpressionAttributeValues=expression_values,
-            )
+            self._table.put_item(**kwargs)
         except botocore.exceptions.ClientError as e:
             if e.response["Error"]["Code"] == "ConditionalCheckFailedException":
                 raise ExpectationNotMet() from e
@@ -173,15 +173,15 @@ class DB:
                 if type(attribute) is dict and name in old_item:
                     for sub_name, sub_attribute in attribute.items():
                         if sub_name not in old_item[name] or old_item[name][sub_name] != sub_attribute:
-                            statements.append(f"SET {name}.{sub_name}=:{name}.{sub_name}")
-                            values[f":{name}.{sub_name}"] = sub_attribute
-                    for old_sub_name in old_item[name]:
+                            statements.append(f"SET {name}.{sub_name}=:{name + sub_name}")
+                            values[f":{name + sub_name}"] = sub_attribute
+                    for old_sub_name in old_item.get(name, {}):
                         if old_sub_name not in attribute:
                             statements.append(f"DELETE {name}.{old_sub_name}")
 
-                elif name not in old_item and old_item[name] != attribute:
+                elif name not in old_item or old_item[name] != attribute:
                     statements.append(f"SET {name}=:{name}")
-                    values["name"] = attribute
+                    values[f":{name}"] = attribute
 
             for old_name in old_item:
                 if old_name not in item:
